@@ -1,10 +1,13 @@
 from abc import ABCMeta, abstractmethod
+from typing import Any, Dict, List, Union
 
-from typing import Union, List, Dict, Any
+from amundsen_common.models.popular_table import PopularTable
+from amundsen_common.models.table import Table
+from amundsen_common.models.user import User as UserEntity
 
-from metadata_service.entity.popular_table import PopularTable
-from metadata_service.entity.user_detail import User as UserEntity
-from metadata_service.entity.table_detail import Table
+from metadata_service.entity.dashboard_detail import DashboardDetail as DashboardDetailEntity
+from metadata_service.entity.description import Description
+from metadata_service.entity.resource_type import ResourceType
 from metadata_service.util import UserResourceRel
 
 
@@ -13,8 +16,13 @@ class BaseProxy(metaclass=ABCMeta):
     Base Proxy, which behaves like an interface for all
     the proxy clients available in the amundsen metadata service
     """
+
     @abstractmethod
-    def get_user_detail(self, *, user_id: str) -> Union[UserEntity, None]:
+    def get_user(self, *, id: str) -> Union[UserEntity, None]:
+        pass
+
+    @abstractmethod
+    def get_users(self) -> List[UserEntity]:
         pass
 
     @abstractmethod
@@ -41,11 +49,11 @@ class BaseProxy(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def add_tag(self, *, table_uri: str, tag: str) -> None:
+    def add_tag(self, *, id: str, tag: str, tag_type: str, resource_type: ResourceType) -> None:
         pass
 
     @abstractmethod
-    def delete_tag(self, *, table_uri: str, tag: str) -> None:
+    def delete_tag(self, *, id: str, tag: str, tag_type: str, resource_type: ResourceType) -> None:
         pass
 
     @abstractmethod
@@ -62,8 +70,7 @@ class BaseProxy(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def get_popular_tables(self, *,
-                           num_entries: int =10) -> List[PopularTable]:
+    def get_popular_tables(self, *, num_entries: int) -> List[PopularTable]:
         pass
 
     @abstractmethod
@@ -79,6 +86,10 @@ class BaseProxy(metaclass=ABCMeta):
                                    relation_type: UserResourceRel) -> Dict[str, Any]:
         pass
 
+    @abstractmethod
+    def get_frequently_used_tables(self, *, user_email: str) -> Dict[str, Any]:
+        pass
+
     @abstractmethod
     def add_table_relation_by_user(self, *,
                                    table_uri: str,
@@ -92,3 +103,20 @@ class BaseProxy(metaclass=ABCMeta):
                                       user_email: str,
                                       relation_type: UserResourceRel) -> None:
         pass
+
+    @abstractmethod
+    def get_dashboard(self,
+                      dashboard_uri: str,
+                      ) -> DashboardDetailEntity:
+        pass
+
+    @abstractmethod
+    def get_dashboard_description(self, *,
+                                  id: str) -> Description:
+        pass
+
+    @abstractmethod
+    def put_dashboard_description(self, *,
+                                  id: str,
+                                  description: str) -> None:
+        pass
